@@ -27,7 +27,7 @@ class TestStress:
             cls.callback_counter += 1
             # if cls.callback_counter % 100 == 0:  # 每100个任务打印一次
             #     print(f"callback: {cls.callback_counter}")
-        print(message_item.id)
+        # print(message_item.id)
         # print(f"callback: {message_item}")
         # print(f"callback: {message_item.id}")
         # print(f"callback: {message_item.expire_time}")
@@ -56,9 +56,7 @@ class TestStress:
         cls.is_monitoring = True
         monitor_thread = threading.Thread(target=cls.monitor_resources, daemon=True)
         monitor_thread.start()
-        queue_scheduler = QueueScheduler(
-            receive_thread_num=4, task_thread_num=8, shard_num=12
-        )
+        queue_scheduler = QueueScheduler()
 
         # threads = []
         # for message_item in messages:
